#line 2 "parser/faustlexer.cpp"

#line 4 "parser/faustlexer.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 134
#define YY_END_OF_BUFFER 135
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[458] =
    {   0,
        0,    0,    2,    2,    0,    0,    0,    0,  135,  133,
      132,  132,   60,  133,   45,   48,   47,   63,   64,   43,
       41,   36,   42,   70,   44,   29,   35,   61,   53,   62,
       55,   46,  127,   67,   69,   68,  104,   59,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,   65,   49,   66,   40,
        2,    5,    6,    3,    9,   10,    9,  134,   27,  134,
       26,  134,  134,  134,  134,  132,   58,    0,  128,   38,
       33,    1,  131,   30,   29,    0,   39,    0,    0,   37,
       51,   54,  130,    0,    0,   57,  125,   56,   52,  127,

      126,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,    2,    4,    3,
        3,    7,    0,    0,    0,    0,    0,    0,   28,    0,
        0,    0,    0,    0,    0,  131,   30,    0,    0,   32,
        0,    0,    0,    0,    0,  126,  107,  127,  127,  127,
      127,  127,  127,  127,  127,  127,   98,  127,  127,  101,
      127,  127,  127,  127,  127,  127,  127,  127,  127,   74,

      127,  102,  109,   72,  108,  127,  116,  105,  127,  127,
      127,  127,  127,  127,  127,  115,   99,  127,  117,  100,
      127,  127,  127,  127,  127,   50,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   34,    0,
       31,  129,    0,    0,    0,    0,   94,   95,   96,  127,
      127,  124,  113,  127,  127,  127,  127,  127,  127,  127,
      127,  110,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  118,  127,  127,  114,  127,  127,  106,  127,  127,
      127,  127,   71,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   21,    0,    0,    0,    0,   97,  127,

      127,  127,  127,  127,  127,  127,  127,   75,  112,  127,
      127,  127,  127,  127,  127,  103,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,    0,    0,    0,    0,
        0,    0,    0,    0,   22,    0,    0,    0,    0,    8,
       93,   83,  127,  127,  127,  127,  127,  127,  127,  127,
       89,  127,  119,  127,   87,   73,  127,  127,  127,  127,
       90,  127,   88,  127,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  127,  127,  123,  127,
      127,  127,  127,  127,   86,  121,   76,  127,   77,   78,
       79,  127,   85,   20,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,   84,  127,  127,  127,  127,
      127,  127,  127,  127,    0,    0,   13,    0,    0,    0,
        0,    0,   24,    0,    0,    0,  120,  127,   81,   80,
       82,   92,  111,   91,   16,    0,    0,    0,   11,    0,
        0,   17,    0,    0,  127,   14,   18,   12,    0,    0,
       15,   19,  122,    0,   25,   23,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    1,    1,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   23,   23,   23,   23,   23,   23,   24,   25,   26,
       27,   28,    1,   29,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       31,   32,   33,   34,   35,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   30,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   30,   60,   61,   62,   63,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[64] =
    {   0,
        1,    1,    2,    2,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    1,    1,    1,    4,    4,    5,    5,
        5,    5,    5,    4,    1,    4,    4,    4,    1,    6,
        1,    1,    1,    1,    5,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    1,
        1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[470] =
    {   0,
        0,    0,   61,   63,   65,   66,   63,   66,  603,  604,
       75,   83,  575,  594,  604,  604,  604,  604,  604,  604,
      572,  604,  604,   75,   88,  102,  571,  604,  109,   44,
       55,  604,    0,  604,  604,  604,  604,    0,   62,  543,
       98,  557,   60,  102,  102,   64,   65,  110,  556,  115,
      113,  121,  124,  126,  551,  545,  604,  604,  604,  604,
        0,  589,  604,  156,  604,  604,  141,  604,  604,  564,
      604,   88,  555,  551,  537,  180,  604,  581,  604,  604,
      171,  604,    0,  176,  183,  198,  604,    0,  168,  604,
      604,  604,  604,  207,  548,  604,  604,  604,  604,    0,

        0,  533,  536,  540,  173,  529,  529,  537,  540,  124,
      541,  522,  527,  527,  520,  525,  524,  536,  535,  518,
      523,  518,  513,  529,  523,  506,  516,  514,  513,  508,
      502,  161,  504,  510,  508,  501,  127,  506,  501,  505,
      503,  498,  513,  496,  501,  492,  493,    0,  604,  219,
      223,  604,  497,  499,  491,  497,  500,  490,  604,  488,
      484,  490,  486,  479,  224,    0,  229,  239,  244,  251,
      505,  488,  480,  490,  480,    0,    0,  475,  479,  478,
      489,  470,  483,  476,  483,  470,    0,  473,  474,    0,
      469,  468,  126,  476,  462,  461,  463,  467,  461,    0,

      457,  488,    0,    0,    0,  453,    0,    0,  465,  466,
      468,  467,  448,  465,  460,    0,    0,  445,    0,    0,
      449,  445,  447,  451,  451,    0,  454,  456,  436,  437,
      435,  434,  447,  432,  432,  446,  443,  256,  261,  266,
      271,  604,  446,  426,  426,  441,    0,    0,  457,  439,
      427,    0,    0,  430,  425,  437,  420,  418,  432,  415,
      416,    0,  423,  424,  410,  425,  411,  426,  442,  408,
      415,    0,  421,  413,    0,  419,  417,    0,  399,  411,
      397,  412,    0,  401,  407,  412,  393,  410,  401,  396,
      391,  402,  387,  604,  398,  403,  402,  409,    0,  393,

      387,  397,  385,  380,  382,  376,  375,    0,    0,  392,
      375,  376,  385,  370,  371,    0,  363,  363,  374,  371,
      372,  363,  366,  363,  364,  373,  374,  359,  356,  365,
      369,  369,  367,  361,  604,  368,  351,  348,  362,  604,
        0,    0,  351,  359,  358,  349,  360,  351,  357,  357,
        0,  340,    0,  332,    0,    0,  350,  350,  348,  108,
        0,  351,    0,  334,  357,  348,  339,  334,  345,  340,
      339,  341,  335,  340,  331,  338,  315,  324,    0,  324,
      322,  320,  322,  317,    0,    0,    0,  326,    0,    0,
        0,  315,    0,  604,  317,  314,  320,  307,  208,  312,

      304,  305,  310,  307,  301,    0,  300,  313,  298,  303,
      310,  306,  296,  304,  318,  297,  604,  308,  319,  303,
      288,  271,  604,  292,  220,  221,    0,  208,    0,    0,
        0,    0,    0,    0,  604,  226,  214,  211,  604,  186,
      189,  604,  200,  194,  132,  604,  604,  604,  105,   92,
      604,  604,    0,   50,  604,  604,  604,  294,  300,  306,
      312,  315,  317,   83,  323,  329,  335,   69,  337
    } ;

static yyconst flex_int16_t yy_def[470] =
    {   0,
      457,    1,  458,  458,  459,  459,  460,  460,  457,  457,
      457,  457,  457,  461,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  462,  457,
      457,  457,  463,  457,  457,  457,  457,  464,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  457,  457,  457,  457,
      465,  457,  457,  466,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  461,  457,  457,
      457,  457,  467,  457,  457,  457,  457,  468,  457,  457,
      457,  457,  457,  462,   94,  457,  457,  457,  457,  463,

      469,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  465,  457,  466,
      466,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  467,  457,  457,  457,  457,
      457,  457,  457,  457,   94,  469,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,

      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,   94,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,   94,  463,  463,

      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  457,  457,  457,  457,  457,  457,  457,

      457,  457,  457,  457,  457,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  463,  463,  463,  463,
      463,  463,  463,  463,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  463,  457,  457,  457,  457,  457,
      457,  457,  463,  457,  457,  457,    0,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457
    } ;

static yyconst flex_int16_t yy_nxt[668] =
    {   0,
       10,   11,   12,   11,   11,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   26,
       26,   26,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   33,   45,   46,   33,   47,   48,   49,   33,   50,
       33,   51,   52,   53,   33,   54,   55,   56,   33,   57,
       58,   59,   60,   62,   63,   62,   63,   66,   66,   69,
       96,   97,   69,   64,  171,   64,   76,   76,   76,   76,
       70,   98,   99,   70,   76,   76,   76,   76,  101,   71,
       67,   67,   71,   81,   81,   81,   81,   81,  102,  103,

       82,   72,  456,   73,   72,   83,   73,  112,  124,   74,
      122,  123,   74,  125,  104,  105,   75,  113,   84,   75,
       85,   85,   85,   85,   85,   88,   89,  160,  390,  391,
      455,  161,   90,  107,   91,   92,   93,  108,  119,  114,
      109,   86,  115,  120,  454,  126,  110,  116,  117,  127,
      130,  133,  134,  128,  121,   95,  135,  118,  153,  141,
      137,  260,  143,  131,  138,  142,  132,  144,  151,  136,
      186,  139,  215,  152,  261,  140,  187,  216,  145,  154,
      155,   76,   76,   76,   76,  453,  156,  157,  158,   81,
       81,   81,   81,   81,  167,  167,  167,  167,  167,   84,

      209,   85,   85,   85,   85,   85,  172,  173,  180,  210,
      165,  169,  419,  169,  174,  168,  170,  170,  170,  170,
      170,  452,   86,   88,  457,  420,  181,  451,  450,  449,
      457,  457,  457,  457,   93,  151,  457,  238,  448,  238,
      152,  447,  239,  239,  239,  239,  239,  167,  167,  167,
      167,  167,  240,  446,  240,  445,  444,  241,  241,  241,
      241,  241,  170,  170,  170,  170,  170,  443,  168,  170,
      170,  170,  170,  170,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,   61,   61,   61,   61,   61,   61,

       65,   65,   65,   65,   65,   65,   68,   68,   68,   68,
       68,   68,   78,   78,   78,   78,   78,   78,   94,  442,
       94,  100,  100,  148,  441,  440,  148,  148,  148,  150,
      439,  150,  150,  150,  150,  166,  438,  166,  166,  166,
      166,  176,  176,  437,  436,  435,  434,  433,  432,  431,
      430,  429,  428,  427,  426,  425,  424,  423,  422,  421,
      418,  417,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  400,  399,
      398,  397,  396,  395,  394,  393,  392,  389,  388,  387,
      386,  385,  384,  383,  382,  381,  380,  379,  378,  377,

      376,  375,  374,  373,  372,  371,  370,  369,  368,  367,
      366,  365,  364,  363,  362,  361,  360,  359,  358,  357,
      356,  355,  354,  353,  352,  351,  350,  349,  348,  347,
      346,  345,  344,  343,  342,  341,  340,  339,  338,  337,
      336,  335,  334,  333,  332,  331,  330,  329,  328,  327,
      326,  325,  324,  323,  322,  321,  320,  319,  318,  317,
      316,  315,  314,  313,  312,  311,  310,  309,  308,  307,
      306,  305,  304,  303,  302,  301,  300,  299,  298,  297,
      296,  295,  294,  293,  292,  291,  290,  289,  288,  287,
      286,  285,  284,  283,  282,  281,  280,  279,  278,  277,

      276,  275,  274,  273,  272,  271,  270,  269,  268,  267,
      266,  265,  264,  263,  262,  259,  258,  257,  256,  255,
      254,  253,  252,  251,  250,  249,  248,  247,  246,  245,
      244,  243,  242,  237,  236,  235,  234,  233,  232,  231,
      230,  229,  228,  227,  226,  225,  224,  223,  222,  221,
      220,  219,  218,  217,  214,  213,  212,  211,  208,  207,
      206,  205,  204,  203,  202,  201,  200,  199,  198,  197,
      196,  195,  194,  193,  192,  191,  190,  189,  188,  185,
      184,  183,  182,  179,  178,  177,  175,   79,  164,  163,
      162,  159,  149,  147,  146,  129,  111,  106,   87,   80,

       79,   77,  457,    9,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457
    } ;

static yyconst flex_int16_t yy_chk[668] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    4,    4,    5,    6,    7,
       30,   30,    8,    3,  468,    4,   11,   11,   11,   11,
        7,   31,   31,    8,   12,   12,   12,   12,  464,    7,
        5,    6,    8,   24,   24,   24,   24,   24,   39,   39,

       25,    7,  454,    7,    8,   25,    8,   43,   47,    7,
       46,   46,    8,   47,   39,   39,    7,   43,   26,    8,
       26,   26,   26,   26,   26,   29,   29,   72,  360,  360,
      450,   72,   29,   41,   29,   29,   29,   41,   45,   44,
       41,   26,   44,   45,  449,   48,   41,   44,   44,   48,
       50,   51,   51,   48,   45,   29,   51,   44,   67,   53,
       52,  193,   54,   50,   52,   53,   50,   54,   64,   51,
      110,   52,  137,   64,  193,   52,  110,  137,   54,   67,
       67,   76,   76,   76,   76,  445,   67,   67,   67,   81,
       81,   81,   81,   81,   84,   84,   84,   84,   84,   85,

      132,   85,   85,   85,   85,   85,   89,   89,  105,  132,
       81,   86,  399,   86,   89,   84,   86,   86,   86,   86,
       86,  444,   85,   94,   94,  399,  105,  443,  441,  440,
       94,  150,   94,   94,   94,  151,  150,  165,  438,  165,
      151,  437,  165,  165,  165,  165,  165,  167,  167,  167,
      167,  167,  168,  436,  168,  428,  426,  168,  168,  168,
      168,  168,  169,  169,  169,  169,  169,  425,  167,  170,
      170,  170,  170,  170,  238,  238,  238,  238,  238,  239,
      239,  239,  239,  239,  240,  240,  240,  240,  240,  241,
      241,  241,  241,  241,  458,  458,  458,  458,  458,  458,

      459,  459,  459,  459,  459,  459,  460,  460,  460,  460,
      460,  460,  461,  461,  461,  461,  461,  461,  462,  424,
      462,  463,  463,  465,  422,  421,  465,  465,  465,  466,
      420,  466,  466,  466,  466,  467,  419,  467,  467,  467,
      467,  469,  469,  418,  416,  415,  414,  413,  412,  411,
      410,  409,  408,  407,  405,  404,  403,  402,  401,  400,
      398,  397,  396,  395,  392,  388,  384,  383,  382,  381,
      380,  378,  377,  376,  375,  374,  373,  372,  371,  370,
      369,  368,  367,  366,  365,  364,  362,  359,  358,  357,
      354,  352,  350,  349,  348,  347,  346,  345,  344,  343,

      339,  338,  337,  336,  334,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  322,  321,  320,  319,
      318,  317,  315,  314,  313,  312,  311,  310,  307,  306,
      305,  304,  303,  302,  301,  300,  298,  297,  296,  295,
      293,  292,  291,  290,  289,  288,  287,  286,  285,  284,
      282,  281,  280,  279,  277,  276,  274,  273,  271,  270,
      269,  268,  267,  266,  265,  264,  263,  261,  260,  259,
      258,  257,  256,  255,  254,  251,  250,  249,  246,  245,
      244,  243,  237,  236,  235,  234,  233,  232,  231,  230,
      229,  228,  227,  225,  224,  223,  222,  221,  218,  215,

      214,  213,  212,  211,  210,  209,  206,  202,  201,  199,
      198,  197,  196,  195,  194,  192,  191,  189,  188,  186,
      185,  184,  183,  182,  181,  180,  179,  178,  175,  174,
      173,  172,  171,  164,  163,  162,  161,  160,  158,  157,
      156,  155,  154,  153,  147,  146,  145,  144,  143,  142,
      141,  140,  139,  138,  136,  135,  134,  133,  131,  130,
      129,  128,  127,  126,  125,  124,  123,  122,  121,  120,
      119,  118,  117,  116,  115,  114,  113,  112,  111,  109,
      108,  107,  106,  104,  103,  102,   95,   78,   75,   74,
       73,   70,   62,   56,   55,   49,   42,   40,   27,   21,

       14,   13,    9,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  457,  457,  457,  457
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[135] =
    {   0,
0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "parser/faustlexer.l"
/* -*- Mode: C++; tab-width: 4; c-basic-offset: 4 -*- */
/* Scanner for the Faust language */
#line 6 "parser/faustlexer.l"
#include "tree.hh"
#include "faustparser.hpp"



#line 781 "parser/faustlexer.cpp"

#define INITIAL 0
#define comment 1
#define doc 2
#define lst 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		unsigned n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 23 "parser/faustlexer.l"



#line 970 "parser/faustlexer.cpp"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 458 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 604 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 26 "parser/faustlexer.l"
BEGIN(comment);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 27 "parser/faustlexer.l"
/* eat anything that's not a '*' 		*/
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 28 "parser/faustlexer.l"
/* eat up '*'s not followed by '/'s 	*/
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 29 "parser/faustlexer.l"
/* no need to increment yylineno here 	*/
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 30 "parser/faustlexer.l"
/* no need to increment yylineno here 	*/
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 31 "parser/faustlexer.l"
/* no need to increment yylineno here 	*/
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 32 "parser/faustlexer.l"
BEGIN(INITIAL);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 34 "parser/faustlexer.l"
{ BEGIN(doc); return BDOC; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 35 "parser/faustlexer.l"
return DOCCHAR; /* char by char, may be slow ?? */
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 36 "parser/faustlexer.l"
return DOCCHAR; /* keep newline chars */
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 37 "parser/faustlexer.l"
return NOTICE;  /* autoclosing tag */
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 38 "parser/faustlexer.l"
return NOTICE;  /* autoclosing tag */
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 39 "parser/faustlexer.l"
{ BEGIN(lst);		return BLST; } /* autoclosing tag */
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 40 "parser/faustlexer.l"
{ BEGIN(INITIAL); 	return BEQN; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 41 "parser/faustlexer.l"
{ BEGIN(doc); 		return EEQN; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 42 "parser/faustlexer.l"
{ BEGIN(INITIAL); 	return BDGM; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 43 "parser/faustlexer.l"
{ BEGIN(doc); 		return EDGM; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 44 "parser/faustlexer.l"
{ BEGIN(INITIAL); 	return BMETADATA; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 45 "parser/faustlexer.l"
{ BEGIN(doc); 		return EMETADATA; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 46 "parser/faustlexer.l"
{ BEGIN(INITIAL); 	return EDOC; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 48 "parser/faustlexer.l"
return LSTTRUE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 49 "parser/faustlexer.l"
return LSTFALSE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 50 "parser/faustlexer.l"
return LSTDEPENDENCIES;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 51 "parser/faustlexer.l"
return LSTMDOCTAGS;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 52 "parser/faustlexer.l"
return LSTDISTRIBUTED;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 53 "parser/faustlexer.l"
return LSTEQ;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 54 "parser/faustlexer.l"
return LSTQ;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 55 "parser/faustlexer.l"
{ BEGIN(doc); 	return ELST; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 58 "parser/faustlexer.l"
return INT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 61 "parser/faustlexer.l"
return FLOAT;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 62 "parser/faustlexer.l"
return FLOAT;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 63 "parser/faustlexer.l"
return FLOAT;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 64 "parser/faustlexer.l"
return FLOAT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 65 "parser/faustlexer.l"
return FLOAT;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 68 "parser/faustlexer.l"
return SEQ;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 69 "parser/faustlexer.l"
return PAR;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 70 "parser/faustlexer.l"
return SPLIT;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 71 "parser/faustlexer.l"
return MIX;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 72 "parser/faustlexer.l"
return MIX;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 73 "parser/faustlexer.l"
return REC;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 75 "parser/faustlexer.l"
return ADD;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 76 "parser/faustlexer.l"
return SUB;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 77 "parser/faustlexer.l"
return MUL;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 78 "parser/faustlexer.l"
return DIV;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 79 "parser/faustlexer.l"
return MOD;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 80 "parser/faustlexer.l"
return FDELAY;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 81 "parser/faustlexer.l"
return DELAY1;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 83 "parser/faustlexer.l"
return AND;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 84 "parser/faustlexer.l"
return OR;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 85 "parser/faustlexer.l"
return XOR;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 87 "parser/faustlexer.l"
return LSH;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 88 "parser/faustlexer.l"
return RSH;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 90 "parser/faustlexer.l"
return LT;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 91 "parser/faustlexer.l"
return LE;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 92 "parser/faustlexer.l"
return GT;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 93 "parser/faustlexer.l"
return GE;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 94 "parser/faustlexer.l"
return EQ;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 95 "parser/faustlexer.l"
return NE;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 97 "parser/faustlexer.l"
return WIRE;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 98 "parser/faustlexer.l"
return CUT;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 100 "parser/faustlexer.l"
return ENDDEF;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 101 "parser/faustlexer.l"
return DEF;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 102 "parser/faustlexer.l"
return LPAR;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 103 "parser/faustlexer.l"
return RPAR;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 104 "parser/faustlexer.l"
return LBRAQ;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 105 "parser/faustlexer.l"
return RBRAQ;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 106 "parser/faustlexer.l"
return LCROC;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 107 "parser/faustlexer.l"
return RCROC;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 109 "parser/faustlexer.l"
return LAMBDA;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 110 "parser/faustlexer.l"
return DOT;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 111 "parser/faustlexer.l"
return WITH;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 113 "parser/faustlexer.l"
return MEM;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 114 "parser/faustlexer.l"
return PREFIX;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 116 "parser/faustlexer.l"
return INTCAST;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 117 "parser/faustlexer.l"
return FLOATCAST;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 119 "parser/faustlexer.l"
return RDTBL;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 120 "parser/faustlexer.l"
return RWTBL;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 122 "parser/faustlexer.l"
return SELECT2;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 123 "parser/faustlexer.l"
return SELECT3;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 125 "parser/faustlexer.l"
return FFUNCTION; 
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 126 "parser/faustlexer.l"
return FCONSTANT; 
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 127 "parser/faustlexer.l"
return FVARIABLE; 
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 129 "parser/faustlexer.l"
return BUTTON;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 130 "parser/faustlexer.l"
return CHECKBOX;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 131 "parser/faustlexer.l"
return VSLIDER;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 132 "parser/faustlexer.l"
return HSLIDER;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 133 "parser/faustlexer.l"
return NENTRY;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 134 "parser/faustlexer.l"
return VGROUP;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 135 "parser/faustlexer.l"
return HGROUP;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 136 "parser/faustlexer.l"
return TGROUP;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 137 "parser/faustlexer.l"
return VBARGRAPH;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 138 "parser/faustlexer.l"
return HBARGRAPH;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 139 "parser/faustlexer.l"
return ATTACH;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 141 "parser/faustlexer.l"
return ACOS;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 142 "parser/faustlexer.l"
return ASIN;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 143 "parser/faustlexer.l"
return ATAN;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 144 "parser/faustlexer.l"
return ATAN2;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 146 "parser/faustlexer.l"
return COS;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 147 "parser/faustlexer.l"
return SIN;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 148 "parser/faustlexer.l"
return TAN;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 150 "parser/faustlexer.l"
return EXP;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 151 "parser/faustlexer.l"
return LOG;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 152 "parser/faustlexer.l"
return LOG10;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 153 "parser/faustlexer.l"
return POWOP;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 154 "parser/faustlexer.l"
return POWFUN;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 155 "parser/faustlexer.l"
return SQRT;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 157 "parser/faustlexer.l"
return ABS;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 158 "parser/faustlexer.l"
return MIN;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 159 "parser/faustlexer.l"
return MAX;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 161 "parser/faustlexer.l"
return FMOD;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 162 "parser/faustlexer.l"
return REMAINDER;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 164 "parser/faustlexer.l"
return FLOOR;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 165 "parser/faustlexer.l"
return CEIL;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 166 "parser/faustlexer.l"
return RINT;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 168 "parser/faustlexer.l"
return ISEQ;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 169 "parser/faustlexer.l"
return IPAR;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 170 "parser/faustlexer.l"
return ISUM;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 171 "parser/faustlexer.l"
return IPROD;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 173 "parser/faustlexer.l"
return IMPORT;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 174 "parser/faustlexer.l"
return COMPONENT;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 175 "parser/faustlexer.l"
return LIBRARY;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 176 "parser/faustlexer.l"
return ENVIRONMENT;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 178 "parser/faustlexer.l"
return DECLARE;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 180 "parser/faustlexer.l"
return CASE;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 181 "parser/faustlexer.l"
return ARROW;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 183 "parser/faustlexer.l"
return IDENT;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 184 "parser/faustlexer.l"
return IDENT;
	YY_BREAK
case 128:
/* rule 128 can match eol */
YY_RULE_SETUP
#line 186 "parser/faustlexer.l"
return STRING;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 188 "parser/faustlexer.l"
return FSTRING;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 189 "parser/faustlexer.l"
return FSTRING;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 192 "parser/faustlexer.l"
/* eat up one-line comments */
	YY_BREAK
case 132:
/* rule 132 can match eol */
YY_RULE_SETUP
#line 194 "parser/faustlexer.l"
/* eat up whitespace */
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(doc):
case YY_STATE_EOF(lst):
#line 196 "parser/faustlexer.l"
yyterminate();
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 198 "parser/faustlexer.l"
printf("extra text is : %s\n", yytext); return EXTRA;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 201 "parser/faustlexer.l"
ECHO;
	YY_BREAK
#line 1745 "parser/faustlexer.cpp"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 458 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 458 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 457);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 201 "parser/faustlexer.l"


int yywrap() { return 1; }


